//Source file: AdditionalCallEventCriteria.java
//Date: December 2004
//Multi Party Call Control Data Types for 3GPP TS 29.198-04-3 V5.9.0

package org.csapi.jr.se.cc;

/**
 * Defines the Tagged Choice of Data Elements that specify specific criteria. 
 *
 */
public final class AdditionalCallEventCriteria implements java.io.Serializable {

    private CallEventType _discriminator = null;
    private java.lang.Object _object;

    /**
     * Creates a new AdditionalCallEventCriteria.
     * Tagged choice of data elements always have empty constructors
     */ 
    public AdditionalCallEventCriteria() {}

    /**
     * This method returns the discriminator.
     * 
     * @return a CallEventType value 
     * @exception InvalidUnionAccessorException if an error occurs 
     */ 
    public CallEventType getDiscriminator() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator == null) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return _discriminator;
    }

    /**
     * This method returns a OriginatingReleaseCauseSet
     * 
     * @return  a org.csapi.jr.se.cc.ReleaseCause[] value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public org.csapi.jr.se.cc.ReleaseCause[] getOriginatingReleaseCauseSet() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != CallEventType.CALL_EVENT_ORIGINATING_RELEASE) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return ((org.csapi.jr.se.cc.ReleaseCause[]) _object);
    }

    /**
     * This method sets a OriginatingReleaseCauseSet
     * 
     * @param value a org.csapi.jr.se.cc.ReleaseCause[] value
     */
    public void setOriginatingReleaseCauseSet(org.csapi.jr.se.cc.ReleaseCause[] value) {
        _discriminator = CallEventType.CALL_EVENT_ORIGINATING_RELEASE;
        _object = value;
    }

    /**
     * This method returns a MinAddressLength
     * 
     * @return  a int value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public int getMinAddressLength() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != CallEventType.CALL_EVENT_ADDRESS_COLLECTED) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Integer) _object).intValue());
    }

    /**
     * This method sets a MinAddressLength
     * 
     * @param value a int value
     */
    public void setMinAddressLength(int value) {
        _discriminator = CallEventType.CALL_EVENT_ADDRESS_COLLECTED;
        _object = new java.lang.Integer(value);
    }

    /**
     * This method returns a TerminatingReleaseCauseSet
     * 
     * @return  a org.csapi.jr.se.cc.ReleaseCause[] value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public org.csapi.jr.se.cc.ReleaseCause[] getTerminatingReleaseCauseSet() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != CallEventType.CALL_EVENT_TERMINATING_RELEASE) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return ((org.csapi.jr.se.cc.ReleaseCause[]) _object);
    }

    /**
     * This method sets a TerminatingReleaseCauseSet
     * 
     * @param value a org.csapi.jr.se.cc.ReleaseCause[] value
     */
    public void setTerminatingReleaseCauseSet(org.csapi.jr.se.cc.ReleaseCause[] value) {
        _discriminator = CallEventType.CALL_EVENT_TERMINATING_RELEASE;
        _object = value;
    }

    /**
     * This method returns a OriginatingServiceCode
     * 
     * @return  a org.csapi.jr.se.cc.CallServiceCode[] value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public org.csapi.jr.se.cc.CallServiceCode[] getOriginatingServiceCode() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != CallEventType.CALL_EVENT_ORIGINATING_SERVICE_CODE) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return ((org.csapi.jr.se.cc.CallServiceCode[]) _object);
    }

    /**
     * This method sets a OriginatingServiceCode
     * 
     * @param value a org.csapi.jr.se.cc.CallServiceCode[] value
     */
    public void setOriginatingServiceCode(org.csapi.jr.se.cc.CallServiceCode[] value) {
        _discriminator = CallEventType.CALL_EVENT_ORIGINATING_SERVICE_CODE;
        _object = value;
    }

    /**
     * This method returns a TerminatingServiceCode
     * 
     * @return  a org.csapi.jr.se.cc.CallServiceCode[] value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public org.csapi.jr.se.cc.CallServiceCode[] getTerminatingServiceCode() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != CallEventType.CALL_EVENT_TERMINATING_SERVICE_CODE) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return ((org.csapi.jr.se.cc.CallServiceCode[]) _object);
    }

    /**
     * This method sets a TerminatingServiceCode
     * 
     * @param value a org.csapi.jr.se.cc.CallServiceCode[] value
     */
    public void setTerminatingServiceCode(org.csapi.jr.se.cc.CallServiceCode[] value) {
        _discriminator = CallEventType.CALL_EVENT_TERMINATING_SERVICE_CODE;
        _object = value;
    }


    /**
     * This method will receive the discriminator as a parameter and will set _object to null
     * 
     * @param discriminator a CallEventType value 
     */ 
    public void setUndefined(CallEventType discriminator) {
        _discriminator = discriminator;
        _object = null;
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) {
            return false;
        }
        if(!(o instanceof AdditionalCallEventCriteria)) {
            return false;
        } else {
            AdditionalCallEventCriteria additionalCallEventCriteria= (AdditionalCallEventCriteria)o;
            if(!(this._object.equals(additionalCallEventCriteria._object))){
                return false;
            } else {
                if(!(this._discriminator.equals(additionalCallEventCriteria._discriminator))){
                    return false;
                }
            }
            if (this.hashCode() != o.hashCode()) {
                return false;
            }
            return true;
        }
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // AdditionalCallEventCriteria

