//Source file: CallNotificationScope.java
//Date: December 2004
//Multi Party Call Control Data Types for 3GPP TS 29.198-04-3 V5.9.0

package org.csapi.jr.se.cc;

/**
 * Defines the sequence of Data elements that specify the scope of a notification request. 
Of the addresses only the Plan and the AddrString are used for the purpose of matching the notifications against the criteria.
 * 
 */
public final class CallNotificationScope implements java.io.Serializable {

    private org.csapi.jr.se.AddressRange destinationAddress;
    private org.csapi.jr.se.AddressRange originatingAddress;

    /**
     * Creates a new CallNotificationScope instance.
     */
    public CallNotificationScope () {}

    /**
     * Creates a new CallNotificationScope instance.
     * @param _destinationAddress   Defines the destination address or address range for which the notification is requested.
     * @param _originatingAddress   Defines the origination address or address range for which the notification is requested.
     */
    public CallNotificationScope (org.csapi.jr.se.AddressRange _destinationAddress, org.csapi.jr.se.AddressRange _originatingAddress) {

        this.destinationAddress = _destinationAddress;
        this.originatingAddress = _originatingAddress;
    }

    /**
     * This method returns a destinationAddress.
     * 
     * @return a org.csapi.jr.se.AddressRange value
     */
    public org.csapi.jr.se.AddressRange getDestinationAddress() {
        return destinationAddress;
    }

    /**
     * This method returns a originatingAddress.
     * 
     * @return a org.csapi.jr.se.AddressRange value
     */
    public org.csapi.jr.se.AddressRange getOriginatingAddress() {
        return originatingAddress;
    }


    /**
     * This method sets a destinationAddress.
     */ 
    public void setDestinationAddress(org.csapi.jr.se.AddressRange destinationAddress) {
        this.destinationAddress = destinationAddress;
    }

    /**
     * This method sets a originatingAddress.
     */ 
    public void setOriginatingAddress(org.csapi.jr.se.AddressRange originatingAddress) {
        this.originatingAddress = originatingAddress;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof CallNotificationScope)) {
            return false;
        } 
        CallNotificationScope callNotificationScope = (CallNotificationScope) o;
        if ((this.destinationAddress != null) && (callNotificationScope.destinationAddress != null)) {
            if(!(this.destinationAddress.equals(callNotificationScope.destinationAddress))) {
                return false;
            }
        }
        if ((this.originatingAddress != null) && (callNotificationScope.originatingAddress != null)) {
            if(!(this.originatingAddress.equals(callNotificationScope.originatingAddress))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // CallNotificationScope

