//Source file: CarrierSelectionField.java
//Date: December 2004
//Multi Party Call Control Data Types for 3GPP TS 29.198-04-3 V5.9.0

package org.csapi.jr.se.cc;

/**
 * Defines the type of Carrier Selection Field-related specific information. This parameter indicates how the selected carrier is provided (for example pre-subscribed).
 *
 */
public final class CarrierSelectionField implements java.io.Serializable {

    private int _value;
    private static int _size = 5;
    private static CarrierSelectionField[] _array = new CarrierSelectionField[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private CarrierSelectionField(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * No indication
     */
    public static final int _CIC_UNDEFINED =  0;

    /**
     * No indication
     */
    public static final CarrierSelectionField CIC_UNDEFINED = new CarrierSelectionField(_CIC_UNDEFINED);

    /**
     * The carrier identification code (CIC) is pre subscribed (not provided by the calling party).
     */
    public static final int _CIC_NO_INPUT =  1;

    /**
     * The carrier identification code (CIC) is pre subscribed (not provided by the calling party).
     */
    public static final CarrierSelectionField CIC_NO_INPUT = new CarrierSelectionField(_CIC_NO_INPUT);

    /**
     * The carrier identification code (CIC) is pre subscribed and provided by the calling party.
     */
    public static final int _CIC_INPUT =  2;

    /**
     * The carrier identification code (CIC) is pre subscribed and provided by the calling party.
     */
    public static final CarrierSelectionField CIC_INPUT = new CarrierSelectionField(_CIC_INPUT);

    /**
     * The selected carrier identification code (CIC) is pre subscribed, but no indication is present of whether it is provided by the calling party (undetermined).
     */
    public static final int _CIC_UNDETERMINED =  3;

    /**
     * The selected carrier identification code (CIC) is pre subscribed, but no indication is present of whether it is provided by the calling party (undetermined).
     */
    public static final CarrierSelectionField CIC_UNDETERMINED = new CarrierSelectionField(_CIC_UNDETERMINED);

    /**
     * The selected carrier identification code (CIC) is provided by calling party (not pre subscribed).
     */
    public static final int _CIC_NOT_PRESCRIBED =  4;

    /**
     * The selected carrier identification code (CIC) is provided by calling party (not pre subscribed).
     */
    public static final CarrierSelectionField CIC_NOT_PRESCRIBED = new CarrierSelectionField(_CIC_NOT_PRESCRIBED);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved CarrierSelectionField object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the CarrierSelectionField object
     */
    public String getValueText() {
        switch (_value) {
            case _CIC_UNDEFINED:
                return "CIC_UNDEFINED";
            case _CIC_NO_INPUT:
                return "CIC_NO_INPUT";
            case _CIC_INPUT:
                return "CIC_INPUT";
            case _CIC_UNDETERMINED:
                return "CIC_UNDETERMINED";
            case _CIC_NOT_PRESCRIBED:
                return "CIC_NOT_PRESCRIBED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 4
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static CarrierSelectionField getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof CarrierSelectionField)) {
            return false;
        }
        CarrierSelectionField carrierSelectionField = (CarrierSelectionField) o; 
        if(!(this.getValue() == carrierSelectionField.getValue())) {
            return false;
        }
        if (this.hashCode() != carrierSelectionField.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // CarrierSelectionField

