//Source file: MultiPartyCall.java
//Date: December 2004
//Multi Party Call Control Interfaces for 3GPP TS 29.198-04-3 V5.9.0

package org.csapi.jr.se.cc.mpccs;

/**
 * This interface represents a MultiPartyCall.<BR>
 *
 */
public interface MultiPartyCall extends org.csapi.jr.se.Service {

    /**
     * Adds a MultiPartyCallListener which is interested in events generated by the MultiPartyCall.
     *
     * @param  multiPartyCallListener  A reference to the MultiPartyCallListener which is to be added as
     *         a listener.
     */
    void addMultiPartyCallListener(org.csapi.jr.se.cc.mpccs.MultiPartyCallListener multiPartyCallListener);

    /**
     * Removes a MultiPartyCallListener which is no longer interested in events generated by the MultiPartyCall.
     *
     * @param  multiPartyCallListener  A reference to the MultiPartyCallListener which is to be removed as
     *         a listener.
     */
    void removeMultiPartyCallListener(org.csapi.jr.se.cc.mpccs.MultiPartyCallListener multiPartyCallListener);

    /**
     * Returns a reference to the MultiPartyCallControlManager responsible for creation of the MultiPartyCall.
     *
     * @return  A reference to the MultiPartyCallControlManager responsible for creation of the MultiPartyCall.
     */
    org.csapi.jr.se.cc.mpccs.MultiPartyCallControlManager getMultiPartyCallControlManager();

    /**
     * Invokes the getCallLegs() method on the Parlay Gateway.
     */
    org.csapi.jr.se.cc.mpccs.CallLeg[] getCallLegs()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the release() method on the Parlay Gateway.
     */
    void release(
           org.csapi.jr.se.cc.ReleaseCause cause)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException;

    /**
     * Invokes the deassignCall() method on the Parlay Gateway.
     */
    void deassignCall()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the getInfoReq() method on the Parlay Gateway.
     */
    void getInfoReq(
           int                             callInfoRequested)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the setChargePlan() method on the Parlay Gateway.
     */
    void setChargePlan(
           org.csapi.jr.se.cc.CallChargePlan callChargePlan)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the setAdviceOfCharge() method on the Parlay Gateway.
     */
    void setAdviceOfCharge(
           org.csapi.jr.se.AoCInfo aOCInfo,
           int                             tariffSwitch)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidCurrencyException,
       org.csapi.jr.se.InvalidAmountException;

    /**
     * Invokes the superviseReq() method on the Parlay Gateway.
     */
    void superviseReq(
           int                             time,
           int                             treatment)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the createCallLeg() method on the Parlay Gateway and returns a reference to a transient interface.
     */
    org.csapi.jr.se.cc.mpccs.CallLeg createCallLeg()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidInterfaceTypeException;

    /**
     * Invokes the createAndRouteCallLegReq() method on the Parlay Gateway and returns a reference to a transient interface.
     */
    org.csapi.jr.se.cc.mpccs.CallLeg createAndRouteCallLegReq(
           org.csapi.jr.se.cc.CallEventRequest[] eventsRequested,
           org.csapi.jr.se.Address targetAddress,
           org.csapi.jr.se.Address originatingAddress,
           org.csapi.jr.se.cc.CallAppInfo[] appInfo)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidInterfaceTypeException,
       org.csapi.jr.se.InvalidAddressException,
       org.csapi.jr.se.UnsupportedAddressPlanException,
       org.csapi.jr.se.InvalidNetworkStateException,
       org.csapi.jr.se.InvalidEventTypeException,
       org.csapi.jr.se.InvalidCriteriaException;

}
